## Installation

Via [pip](https://pip.pypa.io/):

```bash
pip install $PACKAGE$
```

Via [Pipenv](https://pipenv.pypa.io/):

```bash
pipenv install $PACKAGE$
```

Via [Poetry](https://python-poetry.org/):

```bash
poetry add $PACKAGE$
```

Via [PDM](https://pdm.fming.dev/):

```bash
pdm add $PACKAGE$
```

Via [Pyflow](https://github.com/David-OConnor/pyflow):

```bash
pyflow install $PACKAGE$
```
